/**
 * Copyright 2019 Google LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import * as Octokit from '@octokit/rest';
import { IssuesListResponseItem, PullsListResponseItem } from '@octokit/rest';
import { Commit, PREdge } from './graphql-to-commits';
import { Update } from './updaters/update';
export interface OctokitAPIs {
    graphql: Function;
    request: Function;
    octokit: Octokit;
}
interface GitHubOptions {
    token?: string;
    owner: string;
    repo: string;
    apiUrl?: string;
    proxyKey?: string;
    octokitAPIs?: OctokitAPIs;
}
export interface GitHubTag {
    name: string;
    sha: string;
    version: string;
}
export interface GitHubReleasePR {
    number: number;
    version: string;
    sha: string;
}
export interface GitHubFileContents {
    sha: string;
    content: string;
    parsedContent: string;
}
interface GitHubPR {
    branch: string;
    version: string;
    title: string;
    body: string;
    sha: string;
    updates: Update[];
    labels: string[];
}
export declare class GitHub {
    octokit: Octokit;
    request: Function;
    graphql: Function;
    token: string | undefined;
    owner: string;
    repo: string;
    apiUrl: string;
    proxyKey?: string;
    constructor(options: GitHubOptions);
    private graphqlRequest;
    private decoratePaginateOpts;
    commitsSinceSha(sha: string | undefined, perPage?: number, labels?: boolean, path?: string | null): Promise<Commit[]>;
    private commitsWithFiles;
    private commitsWithLabels;
    pullRequestFiles(num: number, cursor: string, maxFilesChanged?: number): Promise<PREdge>;
    getTagSha(name: string): Promise<string>;
    latestTag(perPage?: number): Promise<GitHubTag | undefined>;
    findMergedReleasePR(labels: string[], perPage?: number): Promise<GitHubReleasePR | undefined>;
    private hasAllLabels;
    findOpenReleasePRs(labels: string[], perPage?: number): Promise<PullsListResponseItem[]>;
    private allTags;
    addLabels(pr: number, labels: string[]): Promise<void>;
    findExistingReleaseIssue(title: string, labels: string[], perPage?: number): Promise<IssuesListResponseItem | undefined>;
    openPR(options: GitHubPR): Promise<number>;
    updateFiles(updates: Update[], branch: string, refName: string): Promise<void>;
    private refByBranchName;
    closePR(prNumber: number): Promise<void>;
    getFileContents(path: string): Promise<GitHubFileContents>;
    createRelease(packageName: string, version: string, sha: string, releaseNotes: string): Promise<void>;
    removeLabels(labels: string[], prNumber: number): Promise<void>;
    findFilesByFilename(filename: string): Promise<string[]>;
}
export {};
