/**
 * Copyright 2019 Google LLC. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ConventionalCommits } from './conventional-commits';
import { GitHub, GitHubTag, OctokitAPIs } from './github';
import { Commit } from './graphql-to-commits';
import { Update } from './updaters/update';
export declare enum ReleaseType {
    Node = "node",
    PHPYoshi = "php-yoshi",
    JavaAuthYoshi = "java-auth-yoshi",
    JavaYoshi = "java-yoshi",
    RubyYoshi = "ruby-yoshi"
}
export interface ReleasePROptions {
    bumpMinorPreMajor?: boolean;
    label?: string;
    token?: string;
    repoUrl: string;
    packageName: string;
    releaseAs?: string;
    releaseType: ReleaseType;
    apiUrl: string;
    proxyKey?: string;
    snapshot?: boolean;
    lastPackageVersion?: string;
    octokitAPIs?: OctokitAPIs;
}
export interface ReleaseCandidate {
    version: string;
    previousTag?: string;
}
export declare class ReleasePR {
    apiUrl: string;
    labels: string[];
    gh: GitHub;
    bumpMinorPreMajor?: boolean;
    repoUrl: string;
    token: string | undefined;
    packageName: string;
    releaseAs?: string;
    releaseType: ReleaseType;
    proxyKey?: string;
    snapshot?: boolean;
    lastPackageVersion?: string;
    constructor(options: ReleasePROptions);
    run(): Promise<void>;
    protected _run(): Promise<void>;
    private closeStaleReleasePRs;
    protected coerceReleaseCandidate(cc: ConventionalCommits, latestTag: GitHubTag | undefined): Promise<ReleaseCandidate>;
    protected commits(sha?: string, perPage?: number, labels?: boolean, path?: string | null): Promise<Commit[]>;
    protected gitHubInstance(octokitAPIs?: OctokitAPIs): GitHub;
    protected openPR(sha: string, changelogEntry: string, updates: Update[], version: string, includePackageName?: boolean): Promise<void>;
    protected changelogEmpty(changelogEntry: string): boolean;
}
